<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="si">
<context>
    <name>AirplaneModeItem</name>
    <message>
        <source>Airplane mode enabled</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Airplane mode disabled</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Disable</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Enable</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Airplane Mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Airplane mode settings</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>AirplaneModePlugin</name>
    <message>
        <source>Airplane Mode</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>BluetoothAdapterItem</name>
    <message>
        <source>My Devices</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>BluetoothApplet</name>
    <message>
        <source>Bluetooth settings</source>
        <translation>බ්ලූටූත් සැකසුම්</translation>
    </message>
    <message>
        <source>Turned off</source>
        <translation type="unfinished">වසා දමා ඇත</translation>
    </message>
    <message>
        <source>Disable [Airplane Mode](#) first if you want to connect to a Bluetooth</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>BluetoothItem</name>
    <message>
        <source>Turn off</source>
        <translation>වසා දමන්න</translation>
    </message>
    <message>
        <source>Turn on</source>
        <translation>ක්‍රියාත්මක කරන්න</translation>
    </message>
    <message>
        <source>Bluetooth settings</source>
        <translation>බ්ලූටූත් සැකසුම්</translation>
    </message>
    <message>
        <source>%1 connected</source>
        <translation>%1 සම්බන්ධයි</translation>
    </message>
    <message>
        <source>Connecting...</source>
        <translation>සම්බන්ධ වෙමින්...</translation>
    </message>
    <message>
        <source>Bluetooth</source>
        <translation>බ්ලූටූත්</translation>
    </message>
    <message>
        <source>Turned off</source>
        <translation>වසා දමා ඇත</translation>
    </message>
    <message>
        <source>Connected %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Off</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>BluetoothPlugin</name>
    <message>
        <source>Bluetooth</source>
        <translation>බ්ලූටූත්</translation>
    </message>
</context>
<context>
    <name>BrightnessApplet</name>
    <message>
        <source>Brightness</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Display settings</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>BrightnessItem</name>
    <message>
        <source>Display settings</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>BrightnessPlugin</name>
    <message>
        <source>Brightness</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>CWeekWidget</name>
    <message>
        <source>Sun</source>
        <translation>ඉරි.</translation>
    </message>
    <message>
        <source>Mon</source>
        <translation>සදු.</translation>
    </message>
    <message>
        <source>Tue</source>
        <translation>අග.</translation>
    </message>
    <message>
        <source>Wed</source>
        <translation>බදා.</translation>
    </message>
    <message>
        <source>Thu</source>
        <translation>බ්‍රහස්.</translation>
    </message>
    <message>
        <source>Fri</source>
        <translation>සිකු.</translation>
    </message>
    <message>
        <source>Sat</source>
        <translation>සෙන.</translation>
    </message>
</context>
<context>
    <name>DBusAdaptors</name>
    <message>
        <source>Add keyboard layout</source>
        <translation>යතුරුපුවරු පිරිසැලසුම එක් කරන්න</translation>
    </message>
</context>
<context>
    <name>DatetimePlugin</name>
    <message>
        <source>Datetime</source>
        <translation>දිනය/වේලාව</translation>
    </message>
    <message>
        <source>12-hour time</source>
        <translation>පැය-12 වේලාව</translation>
    </message>
    <message>
        <source>24-hour time</source>
        <translation>පැය-24 වේලාව</translation>
    </message>
    <message>
        <source>Time settings</source>
        <translation>වේලා සැකසුම්</translation>
    </message>
    <message>
        <source>Open the calendar</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DatetimeWidget</name>
    <message>
        <source>Monday</source>
        <translation>සඳුදා</translation>
    </message>
    <message>
        <source>Tuesday</source>
        <translation>අඟහරුවාදා</translation>
    </message>
    <message>
        <source>Wednesday</source>
        <translation>බදාදා</translation>
    </message>
    <message>
        <source>Thursday</source>
        <translation>බ්‍රහස්පතින්දා</translation>
    </message>
    <message>
        <source>Friday</source>
        <translation>සිකුරාදා</translation>
    </message>
    <message>
        <source>Saturday</source>
        <translation>සෙනසුරාදා</translation>
    </message>
    <message>
        <source>Sunday</source>
        <translation>ඉරිදා</translation>
    </message>
    <message>
        <source>monday</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>tuesday</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>wednesday</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>thursday</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>friday</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>saturday</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>sunday</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DeviceControlWidget</name>
    <message>
        <source>Other Devices</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DndModeItem</name>
    <message>
        <source>DND Mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>DND mode settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Disable</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Enable</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>DND mode enabled</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>DND mode disabled</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DndModePlugin</name>
    <message>
        <source>DND Mode</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>EyeComfortModeItem</name>
    <message>
        <source>Eye Comfort</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Eye comfort enabled</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Eye comfort disabled</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Display settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Eye comfort</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Theme</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>On</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Off</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Light</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Dark</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Auto</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Disable eye comfort</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Enable eye comfort</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Display Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Theme: Light</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Theme: Dark</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Theme: Auto</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Visual effect</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>EyeComfortmodeApplet</name>
    <message>
        <source>Light</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Dark</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Auto</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Theme</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>NotificationPlugin</name>
    <message>
        <source>No messages</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Notification settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Notifications</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Turn off DND mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Turn on DND mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Notification</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>OnboardPlugin</name>
    <message>
        <source>Onboard</source>
        <translation>පවතින</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>සැකසුම්</translation>
    </message>
</context>
<context>
    <name>PerformanceModeController</name>
    <message>
        <source>High Performance</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Balanced</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Power Saver</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Balance Performance</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PowerApplet</name>
    <message>
        <source>Power</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PowerPlugin</name>
    <message>
        <source>Power settings</source>
        <translation>බල සැකසුම්</translation>
    </message>
    <message>
        <source>Capacity %1, %2 min remaining</source>
        <translation>ධාරිතාව %1, මිනිත්තු %2 ක් ඉතිරි වී ඇත</translation>
    </message>
    <message>
        <source>Capacity %1, %2 hr %3 min remaining</source>
        <translation>ධාරිතාව %1, පැය %2 මිනිත්තු %3 ක් ඉතිරි වී ඇත</translation>
    </message>
    <message>
        <source>Charging %1, %2 min until full</source>
        <translation>%1 ආරෝපණය වෙමින්, සම්පූර්ණ විමට මිනිත්තු %2</translation>
    </message>
    <message>
        <source>Charging %1, %2 hr %3 min until full</source>
        <translation>%1 ආරෝපණය වෙමින්, සම්පූර්ණ විමට පැය %2 මිනිත්තු %3</translation>
    </message>
    <message>
        <source>Capacity %1</source>
        <translation>ධාරිතාවය %1</translation>
    </message>
    <message>
        <source>Charging %1</source>
        <translation>%1 ආරෝපණය වෙමින්</translation>
    </message>
    <message>
        <source>Capacity %1 ...</source>
        <translation>ධාරිතාවය %1 ...</translation>
    </message>
    <message>
        <source>Capacity %1, fully charged</source>
        <translation>ධාරිතාවය %1, සම්පූර්ණයෙන්ම ආරෝපිතයි</translation>
    </message>
    <message>
        <source>Capacity %1, not charging</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Battery</source>
        <translation>බැටරිය</translation>
    </message>
    <message>
        <source>Charging, calculating estimated charging time</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Calculating remaining usage time</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 min remaining</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 hr %2 min remaining</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Not charging</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Fully charged</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Charging, %1 min until full</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Charging, %1 hr %2 min until full</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Capacity %1, %2 hr remaining</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 hr remaining</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Charging %1, %2 hr until full</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Charging, %1 hr until full</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PowerStatusWidget</name>
    <message>
        <source>Power settings</source>
        <translation type="unfinished">බල සැකසුම්</translation>
    </message>
</context>
<context>
    <name>QuickPanelWidget</name>
    <message>
        <source>Music</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ShutdownPlugin</name>
    <message>
        <source>Shut down</source>
        <translation>වසා දමන්න </translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>තාවකාලිකව වසාදමන්න </translation>
    </message>
    <message>
        <source>Hibernate</source>
        <translation>ශිශිරකරණය කරන්න</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation>අගුළු දමන්න</translation>
    </message>
    <message>
        <source>Log out</source>
        <translation>ඉවත් වන්න</translation>
    </message>
    <message>
        <source>Power settings</source>
        <translation>බල සැකසුම්</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>පද්ධතිය නැවත අරඹන්න</translation>
    </message>
    <message>
        <source>Update and Shut Down</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Update and Reboot</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Shut Down</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Switch user</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SidebarCalendarWidget</name>
    <message>
        <source>Today</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Lunar</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>y</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>m</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>d</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Monday</source>
        <translation type="unfinished">සඳුදා</translation>
    </message>
    <message>
        <source>Tuesday</source>
        <translation type="unfinished">අඟහරුවාදා</translation>
    </message>
    <message>
        <source>Wednesday</source>
        <translation type="unfinished">බදාදා</translation>
    </message>
    <message>
        <source>Thursday</source>
        <translation type="unfinished">බ්‍රහස්පතින්දා</translation>
    </message>
    <message>
        <source>Friday</source>
        <translation type="unfinished">සිකුරාදා</translation>
    </message>
    <message>
        <source>Saturday</source>
        <translation type="unfinished">සෙනසුරාදා</translation>
    </message>
    <message>
        <source>Sunday</source>
        <translation type="unfinished">ඉරිදා</translation>
    </message>
    <message>
        <source>Jan</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Feb</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Mar</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Apr</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>May</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Jun</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Jul</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Aug</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sept</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Oct</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Nov</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Dec</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Open the calendar</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>monday</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>tuesday</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>wednesday</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>thursday</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>friday</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>saturday</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>sunday</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SoundApplet</name>
    <message>
        <source>Volume</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Output</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sound settings</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SoundPlugin</name>
    <message>
        <source>Sound</source>
        <translation>ශබ්දය</translation>
    </message>
</context>
<context>
    <name>SoundView</name>
    <message>
        <source>Unmute</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Mute</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sound settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No output devices</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Volume %1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
